@@ -32,6 +32,7 @@ import android.support.v4.widget.SwipeRefreshLayout;
 import android.util.Log;
 import android.view.ContextMenu;
 import android.view.ContextMenu.ContextMenuInfo;
+import android.view.KeyEvent;
 import android.view.LayoutInflater;
 import android.view.Menu;
 import android.view.MenuInflater;
@@ -65,6 +66,7 @@ import org.videolan.vlc.util.VLCRunnable;
 import org.videolan.vlc.util.WeakHandler;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.concurrent.ConcurrentLinkedQueue;
@@ -87,7 +89,7 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
     private ViewPager mViewPager;
     private SlidingTabLayout mSlidingTabLayout;
     private View mEmptyView;
-    private ArrayList<View> mLists;
+    private List<View> mLists;
 
     public final static int MODE_ARTIST = 0;
     public final static int MODE_ALBUM = 1;
@@ -137,12 +139,7 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
         albumList.setAdapter(mAlbumsAdapter);
         genreList.setAdapter(mGenresAdapter);
 
-
-        mLists = new ArrayList<View>();
-        mLists.add(artistList);
-        mLists.add(albumList);
-        mLists.add(songsList);
-        mLists.add(genreList);
+        mLists = Arrays.asList((View)artistList, albumList, songsList, genreList);
         String[] titles = new String[] {getString(R.string.artists), getString(R.string.albums),
                 getString(R.string.songs), getString(R.string.genres)};
         mViewPager = (ViewPager) v.findViewById(R.id.pager);
@@ -160,10 +157,10 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
         albumList.setOnItemClickListener(albumListListener);
         genreList.setOnItemClickListener(genreListListener);
 
-//        artistList.setOnKeyListener(keyListener);
-//        albumList.setOnKeyListener(keyListener);
-//        songsList.setOnKeyListener(keyListener);
-//        genreList.setOnKeyListener(keyListener);
+        artistList.setOnKeyListener(keyListener);
+        albumList.setOnKeyListener(keyListener);
+        songsList.setOnKeyListener(keyListener);
+        genreList.setOnKeyListener(keyListener);
 
         registerForContextMenu(songsList);
         registerForContextMenu(artistList);
@@ -231,67 +228,45 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
         });
     }
 
-//    // Focus support. Start.
-//    View.OnKeyListener keyListener = new View.OnKeyListener() {
-//        @Override
-//        public boolean onKey(View v, int keyCode, KeyEvent event) {
-//
-//            /* Qualify key action to prevent redundant event
-//             * handling.
-//             *
-//             * ACTION_DOWN occurs before focus change and
-//             * may be used to find if change originated from the
-//             * header or if the header must be updated explicitely with
-//             * a call to mHeader.scroll(...).
-//             */
-//            if (event.getAction() == KeyEvent.ACTION_DOWN) {
-//                int newPosition = mFlingViewPosition;
-//
-//                switch (event.getKeyCode()) {
-//                    case KeyEvent.KEYCODE_DPAD_RIGHT:
-//                        if (newPosition < (MODE_TOTAL - 1))
-//                            newPosition++;
-//                        break;
-//                    case KeyEvent.KEYCODE_DPAD_LEFT:
-//                        if (newPosition > 0)
-//                            newPosition--;
-//                        break;
-//                    case KeyEvent.KEYCODE_DPAD_DOWN:
-//                        mFlingViewPosition = 0xFF;
-//                        break;
-//                    default:
-//                        return false;
-//                }
-//
-//                if (newPosition != mFlingViewPosition) {
-//                    int[] lists = { R.id.artists_list, R.id.albums_list,
-//                        R.id.songs_list, R.id.genres_list };
-//                    ListView vList = (ListView)v.getRootView().
-//                        findViewById(lists[newPosition]);
-//
-//                    if (!mHeader.isFocused())
-//                        mHeader.scroll(newPosition / 3.f);
-//
-//                    if (vList.getCount() == 0)
-//                        mHeader.setNextFocusDownId(R.id.header);
-//                    else
-//                        mHeader.setNextFocusDownId(lists[newPosition]);
-//
-//                    mFlingViewGroup.scrollTo(newPosition);
-//
-//                    // assigned in onSwitched following mHeader.scroll
-//                    mFlingViewPosition = newPosition;
-//
-//                    ((MainActivity)getActivity()).setSearchAsFocusDown(
-//                        vList.getCount() == 0, getView(),
-//                        lists[newPosition]);
-//                }
-//            }
-//
-//            // clean up with MainActivity
-//            return false;
-//        }
-//    };
+    // Focus support. Start.
+    View.OnKeyListener keyListener = new View.OnKeyListener() {
+        @Override
+        public boolean onKey(View v, int keyCode, KeyEvent event) {
+
+            /* Qualify key action to prevent redundant event
+             * handling.
+             */
+            if (event.getAction() == KeyEvent.ACTION_DOWN) {
+                int newPosition = mViewPager.getCurrentItem();
+
+                switch (event.getKeyCode()) {
+                    case KeyEvent.KEYCODE_DPAD_RIGHT:
+                        if (newPosition < (MODE_TOTAL - 1))
+                            newPosition++;
+                        break;
+                    case KeyEvent.KEYCODE_DPAD_LEFT:
+                        if (newPosition > 0)
+                            newPosition--;
+                        break;
+                    default:
+                        return false;
+                }
+
+                if (newPosition != mViewPager.getCurrentItem()) {
+                    ListView vList = (ListView) mLists.get(newPosition);
+
+                    mViewPager.setCurrentItem(newPosition);
+
+                    ((MainActivity)getActivity()).setSearchAsFocusDown(
+                            vList.getCount() == 0, getView(),
+                            vList.getId());
+                }
+            }
+
+            // clean up with MainActivity
+            return false;
+        }
+    };
     // Focus support. End.
 
     OnItemClickListener songListener = new OnItemClickListener() {
@@ -542,11 +517,9 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
             mHandler.sendEmptyMessageDelayed(MSG_LOADING, 300);
 
             ExecutorService tpe = Executors.newSingleThreadExecutor();
-            ArrayList<Runnable> tasks = new ArrayList<Runnable>();
-            tasks.add(updateArtists);
-            tasks.add(updateAlbums);
-            tasks.add(updateSongs);
-            tasks.add(updateGenres);
+            ArrayList<Runnable> tasks = new ArrayList<>(Arrays.asList(updateArtists,
+                    updateAlbums, updateSongs, updateGenres));
+
             //process the visible list first
             tasks.add(0, tasks.remove(mViewPager.getCurrentItem()));
             tasks.add(new Runnable() {
